#
# spec file for package arpwatch
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           arpwatch
Version:        2.1a15
Release:        lp152.6.3.1
Summary:        Keeps Track of Ethernet and IP Address Pairings
License:        BSD-3-Clause
Group:          Productivity/Networking/Diagnostic
Url:            http://www-nrg.ee.lbl.gov/nrg.html
Source:         %{name}-%{version}.tar.bz2
Source10:       arpwatch@.service
Source11:       sysconfig.arpwatch
Source12:       arpwatch.service
Patch0:         arpwatch-2.1a11-chrootbuild.diff
Patch1:         arpwatch-no-source-zero.dif
Patch3:         arpwatch-2.1a11-tokenring.diff
Patch4:         arpwatch-2.1a11-hname-overflow.dif
Patch5:         arpwatch-2.1a11-drop-privs-manpage.dif
Patch6:         arpwatch-2.1a11-drop-privs.dif
Patch7:         arpwatch-2.1a11-emailaddr.dif
Patch8:         arpwatch-2.1a15-massagevendor.patch
Patch9: 	getnameinfo.patch
BuildRequires:  libpcap-devel
BuildRequires:  postfix
BuildRequires:  systemd-rpm-macros
Requires:       arpwatch-ethercodes
Requires(post): %fillup_prereq
Requires(post): coreutils

%description
Arpwatch keeps track of Ethernet and IP address pairings. It logs
activity to syslog and reports certain changes via e-mail.

%package ethercodes-build
Summary:        Tool to create ethercodes.dat from IEEE.org meta data
Group:          Productivity/Networking/Diagnostic

%description ethercodes-build
Tool and required files to create the ethercodes.dat file from the OUI
and company ID data as provided by IEEE.org.  This package is only
needed if you want to build the arpwatch-ethercodes package.

%prep
%setup -q
%patch0 -E
%patch1 -p1 -E
%patch3 -p1 -E
%patch4 -p1 -E
%patch5 -p1 -E
%patch6 -p1 -E
%patch7 -p1 -E
%patch8 -p1
%patch9 -p1

%build
%configure
make ARPDIR=%{_localstatedir}/lib/arpwatch %{?_smp_mflags}

%install
mkdir -p \
    %{buildroot}/%{_tmpfilesdir} \
    %{buildroot}/%{_sbindir} \
    %{buildroot}/%{_datadir}/arpwatch \
    %{buildroot}/%{_mandir}/man8 \
    %{buildroot}%{_fillupdir}
%make_install
# ethercodes.dat is in the arpwatch-ethercodes package
rm -f %{buildroot}/%{_datadir}/arpwatch/ethercodes.dat
for file in massagevendor euppertolower.awk duplicates.awk p.awk; do
	cp -p ${file} %{buildroot}/%{_datadir}/arpwatch
done
make DESTDIR=%{buildroot} install-man
install -Dm 0644 %{SOURCE10} %{buildroot}/%{_unitdir}/arpwatch@.service
install -Dm 0644 %{SOURCE12} %{buildroot}/%{_unitdir}/arpwatch.service
ln -s service %{buildroot}%{_sbindir}/rcarpwatch
install -Dm 0644 %{SOURCE11} \
    %{buildroot}%{_fillupdir}/sysconfig.arpwatch
# own the database files
cat > %{buildroot}%{_tmpfilesdir}/arpwatch.conf <<EOF
# See tmpfiles.d(5) for details
d /var/lib/arpwatch - - - -
f /var/lib/arpwatch/arp.dat - - - -
EOF
mkdir %{buildroot}%{_bindir}
install -m 0755 arp2ethers %{buildroot}%{_bindir}

%pre
%service_add_pre arpwatch.service

%preun
%service_del_preun arpwatch.service

%post
%service_add_post arpwatch.service
%fillup_only
%tmpfiles_create %{_tmpfilesdir}/arpwatch.conf

%postun
%service_del_postun arpwatch.service

%files
%{_unitdir}/arpwatch.service
%{_unitdir}/arpwatch@.service
%{_tmpfilesdir}/arpwatch.conf
%{_sbindir}/rcarpwatch
%{_sbindir}/arpsnmp
%{_sbindir}/arpwatch
%{_bindir}/arp2ethers
%ghost %dir %{_localstatedir}/lib/arpwatch
%ghost %{_localstatedir}/lib/arpwatch/arp.dat
%{_fillupdir}/sysconfig.arpwatch
%{_mandir}/man8/arpsnmp.8%{ext_man}
%{_mandir}/man8/arpwatch.8%{ext_man}
%doc CHANGES FILES README

%files ethercodes-build
%{_datadir}/arpwatch

%changelog
* Thu Jan 28 2021 Johannes Segitz <jsegitz@suse.com>
- Include arp2ethers script (jsc#SLE-17224)
* Tue Feb  5 2019 jsegitz@suse.com
- added getnameinfo.patch to prevent memory leak in gethname
  (bsc#1119851)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sat Aug 12 2017 tchvatal@suse.com
- Remove initscript support. Fix the service initialization to\
  either allow single full client or user has to symlink the instance
  and make sure he can run only one of them. bsc#737527
- Make sure rcarpwatch is working
- Use install commands for installation of files
- Format with spec-cleaner
- Generate temp files using systemd
* Fri Jun 19 2015 lmuelle@suse.com
- Deal with added two whitespaces in more recent oui.txt versions.
  + arpwatch-2.1a15-massagevendor.patch
* Fri Dec  5 2014 lmuelle@suse.com
- Removed executable permission bits from arpwatch@.service file.
* Wed May 14 2014 meissner@suse.com
- added missing %%pre/%%service_add_pre section
* Tue Jan  7 2014 rmilasan@suse.com
- Rework arpwatch.service file to properly support multiple network
  interfaces and arpwatch sysconfig file. (bnc#853384).
* Thu Mar 14 2013 p.drouand@gmail.com
- Drop sysvinit support and add systemd support for opensuse > 11.4
* Wed Jul 18 2012 draht@suse.de
- arpwatch-2.1a11-drop-privs.dif: call initgroups() with pw->pw_gid,
  not NULL, to not have groupid 0 initialized. [bnc#764521]
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Nov 27 2009 mseben@novell.com
- added ARPDIR to build section in spec file, to fix error message
  in logs
* Wed Nov 12 2008 draht@suse.de
- arpwatch-2.1a11-emailaddr.dif for flexibility in sender and
  recipient addresses on commandline.
- arpwatch-2.1a11-drop-privs.dif to run arpwatch as different user
- arpwatch-2.1a11-drop-privs-manpage.dif for the manpage
* Wed Nov 12 2008 draht@suse.de
- start script tuned for multiple interface support and independent
  databases. #149003
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Mon May 14 2007 lrupp@suse.de
- update to 2.1a15
  + let the database files belong to the package
  + build parallel
  + use rpm macros for configure and make
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Apr 18 2005 meissner@suse.de
- Use RPM_OPT_FLAGS.
* Thu Nov 11 2004 lmuelle@suse.de
- Add %%insserv_prereq %%fillup_prereq to prereq.
- Add missing call to %%stop_on_removal (%%preun), %%restart_on_update, and
  %%insserv_cleanup (%%postun).
* Sat Nov  6 2004 lmuelle@suse.de
- Split off massagevendor script and required files as we only need them at
  build time to create the ethercodes.dat file from the IEEE.org meta data.
* Sat Nov  6 2004 lmuelle@suse.de
- Add files needed by massagevendor script, [#48005].
* Fri Jun 25 2004 lmuelle@suse.de
- Update to version 2.1a13.
- Add sysconfig file to allow additional options in the init script.
- Compress source tar ball with bzip2.
- Move IEEE OUI and Company_id file to ethercodes sub package.
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Mon Jan 12 2004 adrian@suse.de
- fix build as user
* Mon Jan 12 2004 adrian@suse.de
- add %%defattr
* Tue Jul 29 2003 aj@suse.de
- Fix for chown changes.
* Thu Jun 12 2003 mmj@suse.de
- Forgot to comment in a line
* Thu Jun 12 2003 mmj@suse.de
- Use BuildRoot
* Wed Feb 26 2003 draht@suse.de
- added /usr/sbin/rcarpwatch symlink (#24163)
* Wed Sep 18 2002 draht@suse.de
- added fileutils to PreReq (#19782)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 22 2002 draht@suse.de
- minor buffer overflow with dns query results, fixed by
  arpwatch-2.1a11-hname-overflow.dif (#18149)
* Mon Jul  8 2002 draht@suse.de
- do not source /etc/rc.config any more.
* Mon Mar 18 2002 draht@suse.de
- minor correction to ethercodes.dat
* Thu Mar 14 2002 draht@suse.de
- added init script (bugzilla #12548)
- fix support for token ring interfaces. Thanks to Bjoern Jacke,
  fixes bugzilla #14504.
- update of vendor table (ethercodes.dat)
* Mon Oct 15 2001 draht@suse.de
- upgrade to version 2.1a11
  syslog(3), but do not send mail for packets from IP 0.0.0.0
* Wed Aug  8 2001 sgf@suse.de
- removed libpcapn from neededforbuild and added libpcap
* Thu Jan 11 2001 draht@suse.de
- New version 2.1a10 fixes tmp file race (security).
* Tue Aug  8 2000 olh@suse.de
- add /usr/share/arpwatch to file list, ethercodes.dat was missing
* Thu Jun  1 2000 kukuk@suse.de
- Use doc macro
* Fri Feb 18 2000 dipa@suse.de
- Changed path for manuals to /usr/share/man and /usr/lib/arpwatch
  to /var/lib/arpwatch for arp.dat and /usr/share/arpwatch for
  ethercodes.dat
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Jul 22 1999 msrex@suse.de
- Fixed postinstall
* Sun Jul 11 1999 ro@suse.de
- libpcap is an extra package now
* Fri Jun 11 1999 msrex@suse.de
- Spec file created from arpwatch-2.1a4.tar.gz by autospec
* Fri Jun 11 1999 msrex@suse.de
- Spec file created from arpwatch-2.1a4.tar.gz by autospec
